DateFormat class
Date format class for formatting dates
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
d(
[DateTime? datetime]) → String - Formats a date as a day of month.
-
format(
[DateTime? dateTime, String pattern = 'yyyy-MM-dd']) → String - Format a DateTime using the pattern
-
H(
[DateTime? datetime]) → String - Formats a time as a 24-hour clock hour.
-
HHmmss(
[DateTime? datetime]) → String -
Formats a time as
HH:mm:ss. -
Hm(
[DateTime? datetime]) → String -
Formats a time as
H:mm. -
hm(
[DateTime? datetime]) → String -
Formats a time as
h:mm a. -
Hms(
[DateTime? datetime]) → String -
Formats a time as
H:mm:ss. -
hms(
[DateTime? datetime]) → String -
Formats a time as
h:mm:ss a. -
M(
[DateTime? datetime]) → String - Formats a date as a month number.
-
m(
[DateTime? datetime]) → String - Formats a time as minutes.
-
ms(
[DateTime? datetime]) → String -
Formats a time as
m:ss. -
s(
[DateTime? datetime]) → String - Formats a time as seconds.
-
y(
[DateTime? datetime]) → String - Formats a date as a year.
-
yMd(
[DateTime? datetime]) → String -
Formats a date as
y/M/d. -
yMMMd(
[DateTime? datetime]) → String -
Formats a date as
MMM d, y. -
yMMMEd(
[DateTime? datetime]) → String -
Formats a date as
EEE, MMM d, y. -
yMMMMEEEEd(
[DateTime? datetime]) → String -
Formats a date as
EEEE, MMMM d, y.