isWeekday property
bool
get
isWeekday
Returns true when this date is Monday through Friday.
Implementation
bool get isWeekday => !isWeekend;
Returns true when this date is Monday through Friday.
bool get isWeekday => !isWeekend;