IterableFindExtension<E> extension
- on
-
- Iterable<
E>
- Iterable<
Methods
-
average(
{num value(dynamic)?}) → num? -
Available on Iterable<
Returns the average of all the values in this iterable, as defined byE> , provided by the IterableFindExtension extensionvalue. -
chunks(
int chunkSize) → Iterable< List< E> > -
Available on Iterable<
Split one large list to limited sub listsE> , provided by the IterableFindExtension extension -
find(
bool test(E element), {E orElse()?}) → E? -
Available on Iterable<
find the first element that satisfies the given predicateE> , provided by the IterableFindExtension extensiontest. -
findIndex(
bool test(E element)) → int -
Available on Iterable<
find the first element index that satisfies the given predicateE> , provided by the IterableFindExtension extensiontest. -
flat<
E> ({int? depth, dynamic toElements(dynamic e)?}) → Iterable< E> -
Available on Iterable<
Flats each element of this Iterable into zero or more elements.E> , provided by the IterableFindExtension extension -
max(
{num value(dynamic)?}) → E -
Available on Iterable<
Returns the element with the maximum value in the iterable.E> , provided by the IterableFindExtension extension -
min(
{num value(dynamic)?}) → E -
Available on Iterable<
Returns the element with the minimum value in the iterable.E> , provided by the IterableFindExtension extension -
sum(
[num addend(dynamic)?]) → num -
Available on Iterable<
Returns the sum of all the values in this iterable, as defined byE> , provided by the IterableFindExtension extensionaddend. -
unique(
[bool comparator(E a, E b)?]) → Iterable< E> -
Available on Iterable<
Returns a new lazy Iterable with unique elements from this collection.E> , provided by the IterableFindExtension extension -
uniqueBy<
K> (K keySelector(E element)) → Iterable< E> -
Available on Iterable<
Returns a new Iterable containing only the elements that have unique keys.E> , provided by the IterableFindExtension extension