NullableMapExtension<K, V> extension
Null-safe convenience methods for nullable maps.
- on
-
- Map<
K, V> ?
- Map<
Properties
- isEmpty → bool
-
Available on Map<
Returns true if this map is null or empty.K, V> ?, provided by the NullableMapExtension extensionno setter - isNotEmpty → bool
-
Available on Map<
Returns true if this map has at least one entry.K, V> ?, provided by the NullableMapExtension extensionno setter -
orEmpty
→ Map<
K, V> -
Available on Map<
Returns this map, or an empty map when it is null.K, V> ?, provided by the NullableMapExtension extensionno setter