isEmpty property
bool
get
isEmpty
Returns true if this map is null or empty.
Implementation
bool get isEmpty => this == null || this!.isEmpty;
Returns true if this map is null or empty.
bool get isEmpty => this == null || this!.isEmpty;