isNotEmpty property
bool
get
isNotEmpty
Returns true if this map has at least one entry.
Implementation
bool get isNotEmpty => this != null && this!.isNotEmpty;
Returns true if this map has at least one entry.
bool get isNotEmpty => this != null && this!.isNotEmpty;