orEmpty property
Map<K, V>
get
orEmpty
Returns this map, or an empty map when it is null.
Implementation
Map<K, V> get orEmpty => this == null ? <K, V>{} : Map<K, V>.from(this!);
Returns this map, or an empty map when it is null.
Map<K, V> get orEmpty => this == null ? <K, V>{} : Map<K, V>.from(this!);