isBlank property
bool
get
isBlank
Returns true if string is null, empty, or only whitespace.
Implementation
bool get isBlank => this == null || this!.trim().isEmpty;
Returns true if string is null, empty, or only whitespace.
bool get isBlank => this == null || this!.trim().isEmpty;