isNotBlank property
bool
get
isNotBlank
Returns true if string has at least one non-whitespace character.
Implementation
bool get isNotBlank => !isBlank;
Returns true if string has at least one non-whitespace character.
bool get isNotBlank => !isBlank;