orEmpty property
String
get
orEmpty
Returns this string, or an empty string when it is null.
Implementation
String get orEmpty => this ?? '';
Returns this string, or an empty string when it is null.
String get orEmpty => this ?? '';