removeWhitespace method
Returns a copy of this string with all whitespace removed.
Implementation
String removeWhitespace() =>
this == null ? '' : this!.replaceAll(RegExp(r'\s+'), '');
Returns a copy of this string with all whitespace removed.
String removeWhitespace() =>
this == null ? '' : this!.replaceAll(RegExp(r'\s+'), '');