trimmed property
String
get
trimmed
Returns a trimmed string, or an empty string when it is null.
Implementation
String get trimmed => this?.trim() ?? '';
Returns a trimmed string, or an empty string when it is null.
String get trimmed => this?.trim() ?? '';