futureAll static method
Waits for all futures and returns results in the original order.
Delegates to the iterable future extension and supports progress, success, error, and staggered start callbacks.
Implementation
static Future<List<dynamic>> futureAll(
Iterable<Future> futures, {
void Function(int, int, Map<int, dynamic>)? onProgress,
void Function(dynamic, int)? onAnySuccess,
void Function(Object, StackTrace, int)? onAnyError,
int delayMillis = 0,
}) {
return futures.all(
onProgress: onProgress,
onAnySuccess: onAnySuccess,
onAnyError: onAnyError,
delayMillis: delayMillis);
}