ListExtension<E> extension
Convenience methods for splitting, deduplicating, and reordering lists.
- on
-
- List<
E>
- List<
Methods
-
chunks(
int chunkSize) → List< List< E> > -
Available on List<
Split one large list to limited sub listsE> , provided by the ListExtension extension -
move(
int oldIndex, int newIndex) → void -
Available on List<
Moves the element atE> , provided by the ListExtension extensionoldIndextonewIndexin place. -
separatedBy(
E separator) → List< E> -
Available on List<
InsertsE> , provided by the ListExtension extensionseparatorbetween every element and returns a new list. -
swap(
int indexA, int indexB) → void -
Available on List<
Swaps two elements in place.E> , provided by the ListExtension extension -
unique(
[bool comparator(E a, E b)?]) → List< E> -
Available on List<
Returns a new lazy List with unique elements from this collection.E> , provided by the ListExtension extension -
uniqueBy<
K> (K keySelector(E element)) → List< E> -
Available on List<
Returns a new List containing only the elements that have unique keys.E> , provided by the ListExtension extension